About us
========

.. include:: ../AUTHORS.rst

.. _citing-imbalanced-learn:

Citing imbalanced-learn
-----------------------

If you use imbalanced-learn in a scientific publication, we would appreciate
citations to the following paper:

